<?Php
session_start();
require_once($_SESSION["realPath"] . "/parametros.php");
require_once($_SESSION["realPath"] . "/class/Erro.php");
require_once($_SESSION["realPath"] . "/class/sgbd/PadraoSGBD.php");
require_once($_SESSION["realPath"] . "/class/sgbd/".PARAM_DB_TYPE.".php");

class Db extends PadraoSGBD{

	var $sgbd;
	
	/**
	 * Construtor
	 * Efetua uma conexao e seleciona o banco de dados com base na classe de SGBD incluida no inicio do arquivo
	 */
	function Db(){
		$this->host     = PARAM_DB_HOST;
		$this->port     = PARAM_DB_PORT;
		$this->user     = PARAM_DB_USER;
		$this->password = PARAM_DB_PASSWORD;
		$this->database = PARAM_DB_DATABASE;
		$this->sgbd     = new MySQL($this->host, $this->port, $this->user, $this->password, $this->database);
		$this->sgbd->conectar()
			or die(Erro::mostraErro($this->sgbd->getErro(), __FILE__, __LINE__)); 
	}
	
	/**
	 * Desconecta com o banco de dados
 	 * @return false - erro, true - consulta enviada 
	 */
	function desconectar(){
		$this->sgbd->desconectar()
			or die(Erro::mostraErro($this->sgbd->getErro(), __FILE__, __LINE__)); 
	}
	
	/**
	 * executa uma instrucao SQL e armazena o resultado em result
	 * @param $query_str Instruo SQL enviada ao servidor 
	 * @return false - erro, true - consulta enviada 
	 */
	function query($sql){
		$this->setStatus(true);

		$this->sgbd->query($sql)
			or $this->setErro($this->sgbd->getErro()); 

		return $this->getStatus();
	}
	
	/**
	 * Retorna o numero de registros encontrados na instruo 'Select'
	 * @return Total de registros encontrados pela instruo SQL
	 */
	function count(){
		return $this->sgbd->count();
	}

	/**
	 * Pega o ID do ultimo registro inserido, somente para campos com AutoIncremento
	 * @return Ultimo Id inserido pelo campo AutoIncremento
	 */
	function getLastId() { 
		return $this->sgbd->getLastId(); 
	} 
	
	/**
	 * Obtm uma linha como uma array numrica
     * @return Array de registros
	 */
	function fetchRow(){
		return $this->sgbd->fetchRow();
	}

	/**
	 * Obtm uma linha como uma matriz associativa, uma matriz numrica, ou ambas
     * @return Array de registros 
	 */
	function fetchArray(){
		return $this->sgbd->fetchArray();
	}
	
	/**
	 * Obtm o resultado de uma linha como um objeto
	 * @return Objeto contendo registros 
	 */
	function fetchObject(){
		return $this->sgbd->fetchObject();
	}	
	
}
?>